TestViewModel class
- Inheritance
-
- Object
- EventViewModel
- TestViewModel
Constructors
- TestViewModel()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
ViewEvent state) → void -
inherited
-
subscribe(
EventObserver o) → void -
inherited
-
test(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
EventObserver o) → bool -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited